"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const benchmark_1 = __importDefault(require("./benchmark"));
const hash_table_1 = require("../lib/hash-table");
class HashTableBenchmark extends benchmark_1.default {
    iterations;
    constructor(iterations = 100000) {
        super();
        this.iterations = iterations;
    }
    generateTestData() {
        return Array.from({ length: this.iterations }, (_, i) => [`key${i}`, `value${i}`]);
    }
    run() {
        const testData = this.generateTestData();
        // Test insertion
        const map = new Map();
        const hashTable = new hash_table_1.HashTable(8192 * 100);
        const mapInsertTime = this.measure(() => {
            for (const [key, value] of testData) {
                map.set(key, value);
            }
        });
        const hashTableInsertTime = this.measure(() => {
            for (const [key, value] of testData) {
                hashTable.insert(key, value);
            }
        });
        // Test lookup
        const mapLookupTime = this.measure(() => {
            for (const [key] of testData) {
                map.get(key);
            }
        });
        const hashTableLookupTime = this.measure(() => {
            for (const [key] of testData) {
                hashTable.get(key);
            }
        });
        // Test deletion
        const mapDeleteTime = this.measure(() => {
            for (const [key] of testData) {
                map.delete(key);
            }
        });
        const hashTableDeleteTime = this.measure(() => {
            for (const [key] of testData) {
                hashTable.remove(key);
            }
        });
        // Print results
        console.log(`\nBenchmark Results (${this.iterations.toLocaleString()} operations):`);
        this.formatResult('Insertion', mapInsertTime, hashTableInsertTime, 'Map', 'HashTable');
        // this.formatResult('Lookup', mapLookupTime, hashTableLookupTime, 'Map', 'HashTable');
        // this.formatResult('Deletion', mapDeleteTime, hashTableDeleteTime, 'Map', 'HashTable');
    }
    benchmarkCustomHashCode() {
        // Create test data with custom hash code implementation
        class CustomKey {
            value;
            constructor(value) {
                this.value = value;
            }
            hashCode() {
                return this.value % 8192;
            }
            equals(other) {
                return this.value === other.value;
            }
        }
        const testData = [];
        for (let i = 0; i < this.iterations; i++) {
            testData.push([new CustomKey(i), i]);
        }
        // Test insertion
        const map = new Map();
        const hashTable = new hash_table_1.HashTable(8192 * 100);
        const mapInsertTime = this.measure(() => {
            for (const [key, value] of testData) {
                map.set(key, value);
            }
        });
        const hashTableInsertTime = this.measure(() => {
            for (const [key, value] of testData) {
                hashTable.insert(key, value);
            }
        });
        // Test lookup
        const mapLookupTime = this.measure(() => {
            for (const [key] of testData) {
                map.get(key);
            }
        });
        const hashTableLookupTime = this.measure(() => {
            for (const [key] of testData) {
                hashTable.get(key);
            }
        });
        // Test deletion
        const mapDeleteTime = this.measure(() => {
            for (const [key] of testData) {
                map.delete(key);
            }
        });
        const hashTableDeleteTime = this.measure(() => {
            for (const [key] of testData) {
                hashTable.remove(key);
            }
        });
        // Print results
        console.log(`\nBenchmark Results with Custom HashCode (${this.iterations.toLocaleString()} operations):`);
        this.formatResult('Insertion', mapInsertTime, hashTableInsertTime, 'Map', 'HashTable');
        this.formatResult('Lookup', mapLookupTime, hashTableLookupTime, 'Map', 'HashTable');
        this.formatResult('Deletion', mapDeleteTime, hashTableDeleteTime, 'Map', 'HashTable');
    }
}
exports.default = HashTableBenchmark;
//# sourceMappingURL=hash-table.js.map